@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.4.3'
+nodeenv_version = '0.5.0'
 
 import sys
 import os
@@ -326,7 +326,6 @@ def install_packages(env_dir, opt):
     """
     logger.info(' * Install node.js packages ... ',
         extra=dict(continued=True))
-
     packages = [package.replace('\n', '') for package in
                     open(opt.requirements).readlines()]
     activate_path = join(env_dir, 'bin', 'activate')
@@ -509,7 +508,22 @@ freeze () {
 # unset irrelavent variables
 deactivate_node nondestructive
 
-NODE_VIRTUAL_ENV="__NODE_VIRTUAL_ENV__"
+# find the directory of this script
+# http://stackoverflow.com/a/246128
+if [ "${BASH_SOURCE}" ] ; then
+    SOURCE="${BASH_SOURCE[0]}"
+
+    while [ -h "$SOURCE" ] ; do SOURCE="$(readlink "$SOURCE")"; done
+    DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
+
+    NODE_VIRTUAL_ENV="$(dirname "$DIR")"
+else
+    # dash not movable. fix use case:
+    #   dash -c " . node-env/bin/activate && node -v"
+    NODE_VIRTUAL_ENV="__NODE_VIRTUAL_ENV__"
+fi
+
+# NODE_VIRTUAL_ENV is the parent of the directory where this script is
 export NODE_VIRTUAL_ENV
 
 _OLD_NODE_VIRTUAL_PATH="$PATH"
